# Live

This is an integration test, because we spend Sepolia ETH to do this.
The reason is for testing contract verification. 

## Requirements

- `SEPOLIA_ZKSYNC_RPC_URL` set to a valid sepolia ZKsync RPC URL
- `smalltestnet` a wallet with some zksync testnet eth